Package: enrichViewNet
Type: Package
Version: 1.8.0
Date: 2023-08-12
Title: From functional enrichment results to biological networks
Description: This package enables the visualization of functional 
    enrichment results as network graphs. First the package enables the 
    visualization of enrichment results, in a format corresponding to the one 
    generated by gprofiler2, as a customizable Cytoscape network. In those 
    networks, both gene datasets (GO terms/pathways/protein complexes) and 
    genes associated to the datasets are represented as nodes. While the 
    edges connect each gene to its dataset(s). The package also provides the 
    option to create enrichment maps from functional enrichment results. 
    Enrichment maps enable the visualization of enriched terms into a network 
    with edges connecting overlapping genes.
Authors@R: c(person("Astrid", "Deschênes", email = "adeschen@hotmail.com",
    role=c("aut", "cre"), comment=c(ORCID = "0000-0001-7846-6749")), 
    person("Pascal", "Belleau", email = "pascal_belleau@hotmail.com",
    role=c("aut"), comment = c(ORCID = "0000-0002-0802-1071")), 
    person("Robert L.", "Faure", email="robert.faure@crchudequebec.ulaval.ca",
    role=c("aut"), comment=c(ORCID="0000-0003-1798-4723")), 
    person("Maria J.", "Fernandes", 
    email="maria.fernandes@crchudequebec.ulaval.ca", role = c("aut"), 
    comment=c(ORCID="0000-0002-3973-025X")),
    person(given="Alexander", family="Krasnitz", email="krasnitz@cshl.edu",
    role=c("aut")),
    person(given="David A.", family="Tuveson",
    email="dtuveson@cshl.edu", 
    role=c("aut"), comment=c(ORCID="0000-0002-8017-2712")))
Encoding: UTF-8
License: Artistic-2.0
Depends: R (>= 4.2.0)
Imports: gprofiler2, strex, RCy3, jsonlite, stringr, enrichplot, DOSE,
        igraph, reshape2, methods
Suggests: BiocStyle, knitr, rmarkdown, ggplot2, scatterpie, ggtangle,
        ggrepel, testthat, ggnetwork, magick
biocViews: BiologicalQuestion, Software, Network, NetworkEnrichment, GO
VignetteBuilder: knitr
URL: https://github.com/adeschen/enrichViewNet,
        https://adeschen.github.io/enrichViewNet/
BugReports: https://github.com/adeschen/enrichViewNet/issues
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/enrichViewNet
git_branch: RELEASE_3_22
git_last_commit: 0359c98
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:49:10 UTC; biocbuild
Author: Astrid Deschênes [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7846-6749>),
  Pascal Belleau [aut] (ORCID: <https://orcid.org/0000-0002-0802-1071>),
  Robert L. Faure [aut] (ORCID: <https://orcid.org/0000-0003-1798-4723>),
  Maria J. Fernandes [aut] (ORCID:
    <https://orcid.org/0000-0002-3973-025X>),
  Alexander Krasnitz [aut],
  David A. Tuveson [aut] (ORCID: <https://orcid.org/0000-0002-8017-2712>)
Maintainer: Astrid Deschênes <adeschen@hotmail.com>
