% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methodsInternal.R
\encoding{UTF-8}
\name{isCytoscapeRunning}
\alias{isCytoscapeRunning}
\title{Verifying that Cytoscape is running}
\usage{
isCytoscapeRunning()
}
\value{
a \code{logical} indicating if Cytoscape is running.
}
\description{
Verifying that Cytoscape is running
}
\examples{

## Test if Cytoscape is running
enrichViewNet:::isCytoscapeRunning()

}
\author{
Astrid Deschênes
}
\keyword{internal}
