% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methodsEmap.R
\encoding{UTF-8}
\name{createEnrichMap}
\alias{createEnrichMap}
\title{Using functional enrichment results in  gprofiler2 format to create  
an enrichment map}
\usage{
createEnrichMap(
  gostObject,
  query,
  source = c("TERM_ID", "GO:MF", "GO:CC", "GO:BP", "KEGG", "REAC", "TF", "MIRNA", "HPA",
    "CORUM", "HP", "WP"),
  termIDs = NULL,
  removeRoot = TRUE,
  showCategory = 30L,
  groupCategory = FALSE,
  categoryLabel = 1,
  categoryNode = 1,
  line = 1,
  ...
)
}
\arguments{
\item{gostObject}{a \code{list} corresponding to gprofiler2 enrichment 
output that contains and that contains 
the results from an enrichment analysis.}

\item{query}{a \code{character} string representing the name of the query 
that is going to be used to generate the graph. The query must exist in the 
\code{gostObject} object.}

\item{source}{a \code{character} string representing the selected source 
that will be used to generate the network. To hand-pick the terms to be 
used, "TERM_ID" should be used and the list of selected term IDs should
be passed through the \code{termIDs} parameter. The possible sources are 
"GO:BP" for Gene Ontology Biological Process, "GO:CC" for Gene Ontology  
Cellular Component, "GO:MF" for Gene Ontology Molecular Function, 
"KEGG" for Kegg, "REAC" for Reactome, "TF" for TRANSFAC, "MIRNA" for 
miRTarBase, "CORUM" for CORUM database, "HP" for Human phenotype ontology
and "WP" for WikiPathways.  Default: "TERM_ID".}

\item{termIDs}{a \code{vector} of \code{character} strings that contains the
term IDS retained for the creation of the network. Default: \code{NULL}.}

\item{removeRoot}{a \code{logical} that specified if the root terms of 
the selected source should be removed (when present). Default: \code{TRUE}.}

\item{showCategory}{a positive \code{integer} representing the maximum 
number of terms to display.  If a \code{integer}, the first 
\code{n} terms will be displayed. If \code{NULL}, all terms  
will be displayed. Default: \code{30L}.}

\item{groupCategory}{a \code{logical} indicating if the categories should 
be grouped. Default: \code{FALSE}.}

\item{categoryLabel}{a positive \code{numeric} representing the amount by 
which plotting category nodes label size should be scaled relative 
to the default (1). Default: \code{1}.s}

\item{categoryNode}{a positive \code{numeric} representing the amount by 
which plotting category nodes should be scaled relative to the default (1).
Default: \code{1}.}

\item{line}{a non-negative \code{numeric} representing the scale of line 
width. Default: \code{1}.}

\item{...}{additional arguments that will be pass to the 
\code{\link[enrichplot]{emapplot}} function.}
}
\value{
a \code{ggplot} object which is the enrichment map for enrichment 
results.
}
\description{
User selected enrichment terms are used to create an enrichment 
map. The selection of the term can by specifying by the 
source of the terms (GO:MF, REAC, TF, etc.) or by listing the selected 
term IDs. The map is only generated when there is at least on 
significant term to graph.
}
\examples{

## Loading dataset containing result from an enrichment analysis done with
## gprofiler2
data(parentalNapaVsDMSOEnrichment)

## Extract query information (only one in this dataset)
query <- unique(parentalNapaVsDMSOEnrichment$result$query)

## Create graph for Gene Ontology - Cellular Component related results
createEnrichMap(gostObject=parentalNapaVsDMSOEnrichment, 
    query=query, source="GO:CC", removeRoot=TRUE)


}
\author{
Astrid Deschênes
}
