% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methodsEmapInternal.R
\encoding{UTF-8}
\name{manageQueryDuplicationInEmap}
\alias{manageQueryDuplicationInEmap}
\title{Change query name when more than one queries have  
the same name}
\usage{
manageQueryDuplicationInEmap(queryList)
}
\arguments{
\item{queryList}{a \code{list} containing the query names.}
}
\value{
a \code{list} with the query names modified for queries   
with duplicated names.
}
\description{
The function adds an unique ID at the name of the query when 
more than one query have the same name.
}
\examples{

## List of query names with duplicated names
queryList <- list("parental_vs_DMSO", "rosa_vs_DMSO", "parental_vs_DMSO", 
    "rosa_vs_DMSO", "parental_vs_Control", "rosa_vs_DMSO")

## Change the query names for the duplicated names
enrichViewNet:::manageQueryDuplicationInEmap(queryList=queryList)
    
}
\author{
Astrid Deschênes
}
\keyword{internal}
