% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methodsInternal.R
\encoding{UTF-8}
\name{createMetaDataSectionCXJSON}
\alias{createMetaDataSectionCXJSON}
\title{Create meta data section for the CX JSON file}
\usage{
createMetaDataSectionCXJSON()
}
\value{
a \code{JSON} object that contains the meta data section related
to the network
}
\description{
Create meta data section for the CX JSON file that contains
the network information
}
\examples{

## Create the JSON object that contains the meta data information
enrichViewNet:::createMetaDataSectionCXJSON()

}
\author{
Astrid Deschênes
}
\keyword{internal}
