% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methodsEmapInternal.R
\encoding{UTF-8}
\name{validateCreateEnrichMapSubSectionArguments}
\alias{validateCreateEnrichMapSubSectionArguments}
\title{Validate common arguments passed to createEnrichMap() and 
createEnrichMapMultiBasic() functions}
\usage{
validateCreateEnrichMapSubSectionArguments(
  showCategory,
  groupCategory,
  categoryLabel,
  categoryNode,
  line
)
}
\arguments{
\item{showCategory}{a positive \code{integer} or a \code{vector} of 
\code{characters} representing terms.  If a \code{integer}, the first 
\code{n} terms will be displayed. If \code{vector} of terms, 
the selected terms will be displayed.}

\item{groupCategory}{a \code{logical} indicating if the categories should 
be grouped.}

\item{categoryLabel}{a positive \code{numeric} representing the amount by 
which plotting category nodes label size should be scaled relative 
to the default (1).}

\item{categoryNode}{a positive \code{numeric} representing he amount by 
which plotting category nodes should be scaled relative to the default (1).}

\item{line}{a non-negative \code{numeric} representing the scale of line 
width.}
}
\value{
\code{TRUE} when all arguments are valid
}
\description{
Validate the common arguments passed to createEnrichMap() and 
createEnrichMapMultiBasic() functions.
}
\examples{

## Check that all arguments are valid
enrichViewNet:::validateCreateEnrichMapSubSectionArguments(
    showCategory=20, groupCategory=FALSE, categoryLabel=1.1, categoryNode=1, 
    line=0.5)

}
\author{
Astrid Deschênes
}
\keyword{internal}
